==> ejc-scientific-impl-3.0.0-20250304.072520-21-sources.jar: com/ejianc/business/scientific/result/bean/PatentRegisterEntity.java <==
package com.ejianc.business.scientific.result.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 专利管理-专利登记
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scientific_patent_register")
public class PatentRegisterEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // projectName
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // orgName
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织(二级单位Id)
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码(二级单位code)
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织(二级单位name)
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="dept_id")
    private Long deptId; // 经办部门
    @TableField(value="dept_name")
    private String deptName; // 经办部门名称
    @TableField(value="patent_name")
    private String patentName; // 专利名称
    @TableField(value="patent_type")
    private Integer patentType; // 专利类型  1-发明 2-实用新型 3-外观
    @TableField(value="memo")
    private String memo; // 专利摘要
    @TableField(value="patent_person")
    private String patentPerson; // 专利权人
    @TableField(value="patent_code")
    private String patentCode; // 专利号
    @TableField(value="apply_date")
    private Date applyDate; // 申请时间
    @TableField(value="approve_date")
    private Date approveDate; // 授权时间
    @TableField(value="validity_date")
    private Integer validityDate; // 有效期-1--10年, 2--20年
    @TableField(value="invent_person")
    private String inventPerson; // 发明人
    @TableField(value="law_type")
    private Integer lawType; // 法律状态 1-有效 2-失效
    @TableField(value="scientific_project_id")
    private Long scientificProjectId; // 所属科研项目id
    @TableField(value="scientific_project_name")
    private String scientificProjectName; // scientificProjectName
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public String getPatentName() {
        return patentName;
    }

    public void setPatentName(String patentName) {
        this.patentName = patentName;
    }
    public Integer getPatentType() {
        return patentType;
    }

    public void setPatentType(Integer patentType) {
        this.patentType = patentType;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getPatentPerson() {
        return patentPerson;
    }

    public void setPatentPerson(String patentPerson) {
        this.patentPerson = patentPerson;
    }
    public String getPatentCode() {
        return patentCode;
    }

    public void setPatentCode(String patentCode) {
        this.patentCode = patentCode;
    }
    public Date getApplyDate() {
        return applyDate;
    }

    public void setApplyDate(Date applyDate) {
        this.applyDate = applyDate;
    }
    public Date getApproveDate() {
        return approveDate;
    }

    public void setApproveDate(Date approveDate) {
        this.approveDate = approveDate;
    }
    public Integer getValidityDate() {
        return validityDate;
    }

    public void setValidityDate(Integer validityDate) {
        this.validityDate = validityDate;
    }
    public String getInventPerson() {
        return inventPerson;
    }

    public void setInventPerson(String inventPerson) {
        this.inventPerson = inventPerson;
    }
    public Integer getLawType() {
        return lawType;
    }

    public void setLawType(Integer lawType) {
        this.lawType = lawType;
    }
    public Long getScientificProjectId() {
        return scientificProjectId;
    }

    public void setScientificProjectId(Long scientificProjectId) {
        this.scientificProjectId = scientificProjectId;
    }
    public String getScientificProjectName() {
        return scientificProjectName;
    }

    public void setScientificProjectName(String scientificProjectName) {
        this.scientificProjectName = scientificProjectName;
    }
    
}

==> ejc-scientific-impl-3.0.0-20250829.061142-90-sources.jar: com/ejianc/business/scientific/result/bean/PatentRegisterEntity.java <==
package com.ejianc.business.scientific.result.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 专利管理-专利登记
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scientific_patent_register")
public class PatentRegisterEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // projectName
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // orgName
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织(二级单位Id)
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码(二级单位code)
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织(二级单位name)
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="dept_id")
    private Long deptId; // 经办部门
    @TableField(value="dept_name")
    private String deptName; // 经办部门名称
    @TableField(value="patent_name")
    private String patentName; // 专利名称
    @TableField(value="patent_type")
    private Integer patentType; // 专利类型  1-发明 2-实用新型 3-外观设计
    @TableField(value="memo")
    private String memo; // 专利摘要
    @TableField(value="patent_person")
    private String patentPerson; // 专利权人
    @TableField(value="patent_code")
    private String patentCode; // 专利号
    @TableField(value="apply_date")
    private Date applyDate; // 申请时间
    @TableField(value="approve_date")
    private Date approveDate; // 授权时间
    @TableField(value="validity_date")
    private Integer validityDate; // 有效期-1--10年, 2--20年
    @TableField(value="invent_person")
    private String inventPerson; // 发明人
    @TableField(value="law_type")
    private Integer lawType; // 法律状态 1-有效 2-失效
    @TableField(value="scientific_project_id")
    private Long scientificProjectId; // 所属科研项目id
    @TableField(value="scientific_project_name")
    private String scientificProjectName; // scientificProjectName
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public String getPatentName() {
        return patentName;
    }

    public void setPatentName(String patentName) {
        this.patentName = patentName;
    }
    public Integer getPatentType() {
        return patentType;
    }

    public void setPatentType(Integer patentType) {
        this.patentType = patentType;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getPatentPerson() {
        return patentPerson;
    }

    public void setPatentPerson(String patentPerson) {
        this.patentPerson = patentPerson;
    }
    public String getPatentCode() {
        return patentCode;
    }

    public void setPatentCode(String patentCode) {
        this.patentCode = patentCode;
    }
    public Date getApplyDate() {
        return applyDate;
    }

    public void setApplyDate(Date applyDate) {
        this.applyDate = applyDate;
    }
    public Date getApproveDate() {
        return approveDate;
    }

    public void setApproveDate(Date approveDate) {
        this.approveDate = approveDate;
    }
    public Integer getValidityDate() {
        return validityDate;
    }

    public void setValidityDate(Integer validityDate) {
        this.validityDate = validityDate;
    }
    public String getInventPerson() {
        return inventPerson;
    }

    public void setInventPerson(String inventPerson) {
        this.inventPerson = inventPerson;
    }
    public Integer getLawType() {
        return lawType;
    }

    public void setLawType(Integer lawType) {
        this.lawType = lawType;
    }
    public Long getScientificProjectId() {
        return scientificProjectId;
    }

    public void setScientificProjectId(Long scientificProjectId) {
        this.scientificProjectId = scientificProjectId;
    }
    public String getScientificProjectName() {
        return scientificProjectName;
    }

    public void setScientificProjectName(String scientificProjectName) {
        this.scientificProjectName = scientificProjectName;
    }
    
}
